@@ -29,10 +29,6 @@
 #ifndef _DDD_BoxEdgeAnnotation_h
 #define _DDD_BoxEdgeAnnotation_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "EdgeA.h"
 #include "Box.h"
 #include "assert.h"
@@ -70,6 +66,7 @@ public:
 
     BoxEdgeAnnotation& operator=(const BoxEdgeAnnotation& src)
     {
+      if (this != &src) {
 	Box *new_box = 0;
 	if (src._box != 0)
 	    new_box = src._box->dup();
@@ -78,7 +75,8 @@ public:
 	    _box->unlink();
 	_box = new_box;
 
-	return *this;
+      }
+      return *this;
     }
 
     // Duplication
