@@ -29,10 +29,6 @@
 #ifndef _DDD_BreakPoint_h
 #define _DDD_BreakPoint_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 //-----------------------------------------------------------------------------
 // A `BreakPoint' stores information about an existing debugger breakpoint.
 //-----------------------------------------------------------------------------
@@ -111,13 +107,14 @@ protected:
     static const string& and_op();
     static bool is_false(const string& cond);
 
-    void process_gdb(string& info_output);
-    void process_dbx(string& info_output);
-    void process_xdb(string& info_output);
-    void process_jdb(string& info_output);
-    void process_pydb(string& info_output);
-    void process_perl(string& info_output);
     void process_bash(string& info_output);
+    void process_dbx(string& info_output);
+    void process_dbg(string& info_output);
+    void process_gdb(string& info_output);
+    void process_jdb(string& info_output);
+    void process_perl(string& info_output);
+    void process_pydb(string& info_output);
+    void process_xdb(string& info_output);
 
 public:
     // Create new breakpoint from INFO_OUTPUT.  ARG denotes the
