@@ -29,11 +29,6 @@
 #ifndef _DDD_BuiltinCallNode_h
 #define _DDD_BuiltinCallNode_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
-
 // A BuiltinCallNode calls a built-in VSL function upon run-time.
 
 
@@ -80,7 +75,7 @@ public:
 	: CallNode(a, type), _index(i)
     {}
 
-    BuiltinCallNode(BuiltinCallNode &node, VSLNode *a,
+    BuiltinCallNode(const BuiltinCallNode &node, VSLNode *a,
 		    const char *type = "BuiltinCallNode")
 	: CallNode(a, type), _index(node._index)
     {}
