@@ -29,10 +29,6 @@
 #ifndef _DDD_ChunkQueue_h
 #define _DDD_ChunkQueue_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include <stdio.h>
 #include <string.h>
 #include "TypeInfo.h"
@@ -116,8 +112,8 @@ public:
     }
 
     // Resources
-    const char *data() { return _data; }
-    int length() { return _length; }
+    const char *data() const { return _data; }
+    int length() const { return _length; }
 };
 
 #endif
