@@ -29,10 +29,6 @@
 #ifndef _DDD_CodeCache_h
 #define _DDD_CodeCache_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "strclass.h"
 #include "bool.h"
 #include "VarArray.h"
@@ -55,18 +51,20 @@ struct CodeCacheEntry {
     {}
     CodeCacheEntry& operator = (const CodeCacheEntry& cce)
     {
-	start = cce.start;
-	end   = cce.end;
-	code  = cce.code;
+        if (this != &cce){
+	  start = cce.start;
+	  end   = cce.end;
+	  code  = cce.code;
+	}
 	return *this;
     }
-    bool operator == (const CodeCacheEntry& cce)
+    bool operator == (const CodeCacheEntry& cce) const
     {
 	return start == cce.start
 	    && end == cce.end
 	    && code == cce.code;
     }
-    bool operator != (const CodeCacheEntry& cce)
+    bool operator != (const CodeCacheEntry& cce) const
     {
 	return !operator==(cce);
     }
