@@ -29,10 +29,6 @@
 #ifndef _DDD_DispGraph_h
 #define _DDD_DispGraph_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 //-----------------------------------------------------------------------------
 // The `DispGraph' class keeps all displayed display expressions
 //-----------------------------------------------------------------------------
@@ -164,7 +160,7 @@ protected:
     BoxPoint adjust_position (DispNode *new_node,
 			      Widget w,
 			      BoxPoint pos,
-			      BoxPoint offset,
+			      const BoxPoint& offset,
 			      BoxPoint grid) const;
 
     // Add a new alias edge
