@@ -29,10 +29,6 @@
 #ifndef _DDD_DispValue_h
 #define _DDD_DispValue_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 //-----------------------------------------------------------------------------
 // A DispValue reads and stores type and value of a displayed expression
 //-----------------------------------------------------------------------------
@@ -203,7 +199,7 @@ protected:
     DispValue (const DispValue& dv);
 
     // Return a `normalized' prefix BASE for arrays and structs
-    string normalize_base(const string& base);
+    string normalize_base(const string& base) const;
 
 public:
     // Global settings
