@@ -29,10 +29,6 @@
 #ifndef _DDD_GraphNodePointerArray_h
 #define _DDD_GraphNodePointerArray_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "GraphNode.h"
 #include "VarArray.h"
 
