@@ -36,10 +36,6 @@
 #ifndef _DDD_Map_h
 #define _DDD_Map_h
 
-#if defined(__GNUC_MINOR__) && (__GNUC_MINOR__ >= 5)
-#pragma interface
-#endif
-
 #include "bool.h"
 #include "assert.h"
 
