@@ -29,10 +29,6 @@
 #ifndef _DDD_PlotAgent_h
 #define _DDD_PlotAgent_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "LiterateA.h"
 #include "assert.h"
 #include "StringA.h"
@@ -77,7 +73,7 @@ protected:
     void add_y(double y);
 
     void reset();
-    string var(const char *name, double min, double max);
+    string var(const char *name, double min, double max) const;
 
     virtual void dispatch(int type, const char *data, int length);
 
