@@ -30,10 +30,6 @@
 #ifndef _DDD_Queue_h
 #define _DDD_Queue_h
 
-#if defined(__GNUC_MINOR__) && (__GNUC_MINOR__ >= 5)
-#pragma interface
-#endif
-
 #include "bool.h"
 #include "assert.h"
 
@@ -131,7 +127,7 @@ public:
     }
 
     // Add after A
-    void enqueue_after(const E& e, QueueIter<E> a)
+    void enqueue_after(const E& e, const QueueIter<E>& a)
     {
 	QueueRec<E> *rec = new QueueRec<E>(e);
 	QueueRec<E> *after = a.theRec();
@@ -219,7 +215,8 @@ public:
     {}
     QueueIter<E>& operator = (const QueueIter<E>& iter)
     {
-	rec = iter.rec;
+        if (this != &iter)
+	  rec = iter.rec;
 	return *this;
     }
     QueueIter<E>& operator = (const Queue<E>& queue)
