@@ -47,10 +47,6 @@
 #ifndef _DDD_SourceView_h
 #define _DDD_SourceView_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 // Motif includes
 #include <Xm/Xm.h>
 
@@ -159,7 +155,7 @@ class SourceView {
 
     // Create text or code widget
     static void create_text(Widget parent,
-			    const string& base, bool editable,
+			    const char *base, bool editable,
 			    Widget& form, Widget& text);
 
     // Refresh displays
@@ -191,29 +187,29 @@ class SourceView {
     // * If MAKE_FALSE is == 0, enable breakpoint by restoring
     //   the original condition.
     // * Otherwise, preserve the condition state.
-    static void _set_bps_cond(IntArray& nrs, const string& cond, 
+    static void _set_bps_cond(const IntArray& nrs, const string& cond, 
 			      int make_false, Widget origin);
 
     // Set condition of breakpoints NRS to COND.
-    inline static void set_bps_cond(IntArray& nrs, const string& cond,
+    inline static void set_bps_cond(const IntArray& nrs, const string& cond,
 				    Widget origin = 0)
     {
 	_set_bps_cond(nrs, cond, -1, origin);
     }
 
     // Enable and disable breakpoints via conditions.
-    inline static void set_bps_cond_enabled(IntArray& nrs, bool enabled,
+    inline static void set_bps_cond_enabled(const IntArray& nrs, bool enabled,
 					    Widget origin = 0)
     {
 	_set_bps_cond(nrs, char(-1), enabled ? 0 : 1, origin);
     }
 
     // Custom calls
-    inline static void enable_bps_cond(IntArray& nrs, Widget origin = 0)
+    inline static void enable_bps_cond(const IntArray& nrs, Widget origin = 0)
     {
 	set_bps_cond_enabled(nrs, true, origin);
     }
-    inline static void disable_bps_cond(IntArray& nrs, Widget origin = 0)
+    inline static void disable_bps_cond(const IntArray& nrs, Widget origin = 0)
     {
 	set_bps_cond_enabled(nrs, false, origin);
     }
@@ -371,10 +367,10 @@ class SourceView {
     static StringArray bad_files;
     static bool new_bad_file(const string& file_name);
     static void post_file_error(const string& file_name,
-				string text, const _XtString name = 0,
+				const string& text, const _XtString name = 0,
 				Widget origin = 0);
     static void post_file_warning(const string& file_name,
-				  string text, const _XtString name = 0,
+				  const string& text, const _XtString name = 0,
 				  Widget origin = 0);
 
     // The current directory
@@ -511,13 +507,13 @@ class SourceView {
 
 public:
     // Horizontal arrow offset (pixels)
-    static int arrow_x_offset;
+    static Position arrow_x_offset;
 
     // Horizontal breakpoint symbol offset (pixels)
-    static int stop_x_offset;
+    static Position stop_x_offset;
 
     // Additional offset for multiple breakpoints (pixels)
-    static int multiple_stop_x_offset;
+    static Position multiple_stop_x_offset;
 
 private:
     // Glyph locations: X[0] is source, X[1] is code
@@ -631,7 +627,7 @@ public:
     static void process_info_line_main  (string& info_output);
 
     // Handle 'where' information
-    static void process_where           (string& where_output);
+    static void process_where           (const string& where_output);
 
     // Handle 'frame' information
     static void process_frame           (string& frame_output);
@@ -766,7 +762,7 @@ public:
     // breakpoint temporary.  If COND is given, break only iff COND
     // evals to true.  ORIGIN is the origin.
     static void set_bp(const string& a, bool set, bool temp, 
-		       const string& cond = "", Widget origin = 0);
+		       const char *cond = "", Widget origin = 0);
 
     // Custom calls
     static void create_bp(const string& a, Widget origin = 0);
@@ -777,9 +773,9 @@ public:
     static void temp_n_cont(const string& a, Widget origin = 0);
 
     // Enable/Disable/Delete/Edit breakpoints
-    static void enable_bps     (IntArray& nrs, Widget origin = 0);
-    static void disable_bps    (IntArray& nrs, Widget origin = 0);
-    static void delete_bps     (IntArray& nrs, Widget origin = 0);
+    static void enable_bps     (const IntArray& nrs, Widget origin = 0);
+    static void disable_bps    (const IntArray& nrs, Widget origin = 0);
+    static void delete_bps     (const IntArray& nrs, Widget origin = 0);
     static void edit_bps       (IntArray& nrs, Widget origin = 0);
 
     inline static void enable_bp(int nr, Widget origin = 0)
