@@ -29,10 +29,6 @@
 #ifndef _DDD_ThemeManager_h
 #define _DDD_ThemeManager_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "StringTPA.h"
 #include "ThemeP.h"
 #include <iostream>
@@ -67,7 +63,8 @@ public:
     // Assignment
     ThemeManager& operator = (const ThemeManager& t)
     {
-	map = t.map;
+        if (this != &t)
+	  map = t.map;
 	return *this;
     }
 
@@ -75,13 +72,13 @@ public:
     friend std::ostream& operator<<(std::ostream& os, const ThemeManager& t);
 
     // Get list of themes for an expression
-    StringArray themes(const string& expr);
+    StringArray themes(const string& expr) const;
 
     // Get all themes
-    StringArray themes();
+    StringArray themes() const;
 
     // Check wether pattern exists
-    bool has_pattern(const string& theme)
+    bool has_pattern(const string& theme) const
     {
 	return map.has(theme);
     }
