@@ -29,11 +29,6 @@
 #ifndef _DDD_TrueNode_h
 #define _DDD_TrueNode_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
-
 #include "ConstNode.h"
 #include "ListNode.h"
 
@@ -49,6 +44,9 @@ public:
     TrueNode()
 	: ConstNode(new TrueBox)
     {}
+private:
+    TrueNode(const TrueNode&);
+    TrueNode& operator = (const TrueNode&);
 };
 
 class FalseNode: public ConstNode {
@@ -58,6 +56,9 @@ public:
     FalseNode()
 	: ConstNode(new FalseBox)
     {}
+private:
+    FalseNode(const FalseNode&);
+    FalseNode& operator = (const FalseNode&);
 };
 
 class NullNode: public ConstNode {
@@ -67,6 +68,9 @@ public:
     NullNode()
 	: ConstNode(new NullBox)
     {}
+private:
+    NullNode(const NullNode&);
+    NullNode& operator = (const NullNode&);
 };
 
 class StringNode: public ConstNode {
@@ -76,6 +80,9 @@ public:
     StringNode(const string &str)
 	: ConstNode(new StringBox(str))
     {}
+private:
+    StringNode(const StringNode&);
+    StringNode& operator = (const StringNode&);
 };
 
 class NumNode: public ConstNode {
@@ -85,6 +92,9 @@ public:
     NumNode(int num)
 	: ConstNode(new SquareBox(num))
     {}
+private:
+    NumNode(const NumNode&);
+    NumNode& operator = (const NumNode&);
 };
 
 class EmptyListNode: public ConstNode {
@@ -94,6 +104,9 @@ public:
     EmptyListNode()
 	: ConstNode(new ListBox)
     {}
+private:
+    EmptyListNode(const EmptyListNode&);
+    EmptyListNode& operator = (const EmptyListNode&);
 };
 
 class FixListNode: public ListNode {
@@ -105,6 +118,9 @@ public:
     FixListNode(VSLNode *arg1, VSLNode *arg2);
     FixListNode(VSLNode *arg1, VSLNode *arg2, VSLNode *arg3);
     FixListNode(VSLNode *arg1, VSLNode *arg2, VSLNode *arg3, VSLNode *arg4);
+private:
+    FixListNode(const FixListNode&);
+    FixListNode& operator = (const FixListNode&);
 };
 
 #endif
