@@ -1,4 +1,4 @@
-// $Id: attribute.h,v 1.1 2003/10/01 14:31:56 arnaud02 Exp $ -*- C++ -*-
+// $Id: attribute.h,v 1.3 2004/06/07 11:52:54 arnaud02 Exp $ -*- C++ -*-
 // Provide macros for compiler attributes.
 
 // Copyright (C) 2003 Free Software Foundation, USA.
@@ -29,10 +29,6 @@
 #ifndef _DDD_attribute_h
 #define _DDD_attribute_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "config.h"
 
 #if HAVE_ATTRIBUTE_NORETURN
@@ -41,6 +37,13 @@
 # define ATTRIBUTE_NORETURN
 #endif
 
+#if HAVE_BUILTIN_EXPECT
+# define likely(x) (__builtin_expect(!!(x),1))
+# define unlikely(x) (__builtin_expect(!!(x),0))
+#else
+# define likely(x) (x)
+# define unlikely(x) (x)
+#endif
 
 #endif // _DDD_attribute_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
