@@ -37,10 +37,6 @@
 #ifndef _DDD_comm_manag_h
 #define _DDD_comm_manag_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "GDBAgent.h"
 #include "Command.h"
 
@@ -66,7 +62,7 @@ bool is_known_command(const string& answer);
 // Send commands to initialize a session.  If TRY_SOURCE is set, try
 // the GDB `source' command.
 void init_session(const string& restart, const string& settings,
-		  bool try_source = false);
+		  Boolean try_source = False);
 
 // Let DDD handle COMMAND
 void internal_command(const string& command, OQCProc callback, void *data,
