@@ -3,10 +3,10 @@
 "#line 1 \"<command line>\"\n"
 "#line 1 \"ddd.vsl\"\n"
 "#line 31 \"ddd.vsl\"\n"
-"#line 1 \"../vsllib/std.vsl\"\n"
-"#line 29 \"../vsllib/std.vsl\"\n"
-"#line 1 \"../vsllib/builtin.vsl\"\n"
-"#line 32 \"../vsllib/builtin.vsl\"\n"
+"#line 1 \"./../vsllib/std.vsl\"\n"
+"#line 29 \"./../vsllib/std.vsl\"\n"
+"#line 1 \"./../vsllib/builtin.vsl\"\n"
+"#line 32 \"./../vsllib/builtin.vsl\"\n"
 "__op_halign(...);\n"
 "__op_valign(...);\n"
 "__op_ualign(...);\n"
@@ -95,7 +95,7 @@
 "fail() = __fail();\n"
 "fail(message) = __fail(message);\n"
 "undef() = __undef();\n"
-"#line 30 \"../vsllib/std.vsl\"\n"
+"#line 30 \"./../vsllib/std.vsl\"\n"
 "\n"
 "\n"
 "std_version() = \"$Id$\";\n"
@@ -293,12 +293,12 @@
 "squote() = \"'\";\n"
 "copyright() = \"(c)\";\n"
 "#line 32 \"ddd.vsl\"\n"
-"#line 1 \"../vsllib/tab.vsl\"\n"
-"#line 29 \"../vsllib/tab.vsl\"\n"
-"#line 1 \"../vsllib/std.vsl\"\n"
-"#line 29 \"../vsllib/std.vsl\"\n"
-"#line 1 \"../vsllib/builtin.vsl\"\n"
-"#line 32 \"../vsllib/builtin.vsl\"\n"
+"#line 1 \"./../vsllib/tab.vsl\"\n"
+"#line 29 \"./../vsllib/tab.vsl\"\n"
+"#line 1 \"./../vsllib/std.vsl\"\n"
+"#line 29 \"./../vsllib/std.vsl\"\n"
+"#line 1 \"./../vsllib/builtin.vsl\"\n"
+"#line 32 \"./../vsllib/builtin.vsl\"\n"
 "__op_halign(...);\n"
 "__op_valign(...);\n"
 "__op_ualign(...);\n"
@@ -387,7 +387,7 @@
 "fail() = __fail();\n"
 "fail(message) = __fail(message);\n"
 "undef() = __undef();\n"
-"#line 30 \"../vsllib/std.vsl\"\n"
+"#line 30 \"./../vsllib/std.vsl\"\n"
 "\n"
 "\n"
 "std_version() = \"$Id$\";\n"
@@ -584,11 +584,11 @@
 "dquote() = \"\\\"\";\n"
 "squote() = \"'\";\n"
 "copyright() = \"(c)\";\n"
-"#line 30 \"../vsllib/tab.vsl\"\n"
+"#line 30 \"./../vsllib/tab.vsl\"\n"
 "\n"
 "\n"
 "tab_version() = \"$Id$\";\n"
-"#line 47 \"../vsllib/tab.vsl\"\n"
+"#line 47 \"./../vsllib/tab.vsl\"\n"
 "tab_elem([]) = tab_elem(0);\n"
 "tab_elem(x) = whiteframe(x);\n"
 "\n"
@@ -670,8 +670,8 @@
 "| _dtab(_tab_width(...), ...)\n"
 "| hrule();\n"
 "#line 33 \"ddd.vsl\"\n"
-"#line 1 \"../vsllib/fonts.vsl\"\n"
-"#line 30 \"../vsllib/fonts.vsl\"\n"
+"#line 1 \"./../vsllib/fonts.vsl\"\n"
+"#line 30 \"./../vsllib/fonts.vsl\"\n"
 "fonts_version() = \"$Id$\";\n"
 "\n"
 "\n"
@@ -803,20 +803,20 @@
 "sl(...) = it(...);\n"
 "bs(...) = bi(...);\n"
 "#line 34 \"ddd.vsl\"\n"
-"#line 1 \"../vsllib/colors.vsl\"\n"
-"#line 30 \"../vsllib/colors.vsl\"\n"
+"#line 1 \"./../vsllib/colors.vsl\"\n"
+"#line 30 \"./../vsllib/colors.vsl\"\n"
 "colors_version() = \"$Id$\";\n"
 "\n"
 "\n"
 "color(box, fg, bg) = foreground(background(box, bg), fg);\n"
 "color(box, fg) = foreground(box, fg);\n"
 "#line 35 \"ddd.vsl\"\n"
-"#line 1 \"../vsllib/list.vsl\"\n"
-"#line 29 \"../vsllib/list.vsl\"\n"
-"#line 1 \"../vsllib/std.vsl\"\n"
-"#line 29 \"../vsllib/std.vsl\"\n"
-"#line 1 \"../vsllib/builtin.vsl\"\n"
-"#line 32 \"../vsllib/builtin.vsl\"\n"
+"#line 1 \"./../vsllib/list.vsl\"\n"
+"#line 29 \"./../vsllib/list.vsl\"\n"
+"#line 1 \"./../vsllib/std.vsl\"\n"
+"#line 29 \"./../vsllib/std.vsl\"\n"
+"#line 1 \"./../vsllib/builtin.vsl\"\n"
+"#line 32 \"./../vsllib/builtin.vsl\"\n"
 "__op_halign(...);\n"
 "__op_valign(...);\n"
 "__op_ualign(...);\n"
@@ -905,7 +905,7 @@
 "fail() = __fail();\n"
 "fail(message) = __fail(message);\n"
 "undef() = __undef();\n"
-"#line 30 \"../vsllib/std.vsl\"\n"
+"#line 30 \"./../vsllib/std.vsl\"\n"
 "\n"
 "\n"
 "std_version() = \"$Id$\";\n"
@@ -1102,7 +1102,7 @@
 "dquote() = \"\\\"\";\n"
 "squote() = \"'\";\n"
 "copyright() = \"(c)\";\n"
-"#line 30 \"../vsllib/list.vsl\"\n"
+"#line 30 \"./../vsllib/list.vsl\"\n"
 "\n"
 "\n"
 "list_version() = \"$Id$\";\n"
