@@ -29,10 +29,6 @@
 #ifndef _DDD_deref_h
 #define _DDD_deref_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "strclass.h"
 
 // Return dereferenced EXPR
