@@ -67,6 +67,9 @@ bool is_perl_file(const string& file_name);
 // True if FILE_NAME is a BASH file
 bool is_bash_file(const string& file_name);
 
+// True if FILE_NAME is a PHP file
+bool is_php_file(const string& file_name);
+
 // True if FILE_NAME is a PYTHON file
 bool is_python_file(const string& file_name);
 
