@@ -406,10 +406,6 @@ Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #ifndef _ICE_strclass_h
 #define _ICE_strclass_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include <iostream>
 #include <sstream>
 #include "rxclass.h"
@@ -887,6 +883,12 @@ public:
     bool OK() const;
 };
 
+// Inject names manually to accomodate argument-dependent name lookup (ADL)
+// (aka Koenig lookup). The rule is that friend declarations are visible
+// when found through ADL because an argument of the call happens to be
+// associated with a class of which the function is a friend.
+string replicate(char c, int n);
+
 #if 0
 typedef string strTmp; // for backward compatibility
 #endif
@@ -1146,45 +1148,6 @@ inline string& string::operator = (std::ostringstream& os)
     return *this;
 }
 
-#if 0
-// Phased out
-#include <strstream>
-
-inline string& string::operator = (std::ostrstream& os)
-{
-    assert(!consuming());
-
-    // No need to freeze the stream, since the string is copied right away
-#if HAVE_FROZEN_OSTRSTREAMBUF
-    const int frozen = os.rdbuf()->frozen();
-#elif HAVE_FROZEN_OSTRSTREAM
-    const int frozen = os.frozen();
-#else
-    const int frozen = 0; // Pretty optimistic ...
-#endif
-
-    const char *str = os.str();
-
-#if OSTRSTREAM_PCOUNT_BROKEN
-    // In the SGI C++ I/O library, accessing os.str() *increases*
-    // os.pcount() by 1.  We could compensate this in a
-    // machine-independent way by fetching pcount() before str(), but
-    // this will cause trouble when os is assigned the next time.
-    rep = string_Salloc(rep, str, os.pcount() - 1, os.pcount() - 1);
-#else
-    rep = string_Salloc(rep, str, os.pcount(), os.pcount());
-#endif
-
-#if HAVE_FREEZE_OSTRSTREAMBUF
-    os.rdbuf()->freeze(frozen);
-#elif HAVE_FREEZE_OSTRSTREAM
-    os.freeze(frozen);
-#endif
-    
-    return *this;
-}
-#endif
-
 inline string::string(std::ostringstream& os)
     : rep(&_nilstrRep)
 #if STRING_CHECK_CONSUME
@@ -1992,7 +1955,7 @@ inline std::ostream& operator<<(std::ostream& s, const subString& x)
 // A zillion comparison operators - for every combination of char,
 // char *, const char *, string, and subString.
 #define string_COMPARE(op, t1, t2) \
-inline int operator op(t1 x, t2 y) \
+inline bool operator op(t1 x, t2 y) \
 { \
     return compare(x, y) op 0; \
 }
