@@ -1,4 +1,4 @@
-# $Id: yacctoC.h,v 1.9 2000/05/29 14:07:29 andreas Exp $
+# $Id$
 # Adapt BISON/YACC header output for C++ usage
 
 # Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -29,12 +29,13 @@
 # Declare functions
 1i\
 // This file was modified for -*- C++ -*-\
-// using $RCSfile: yacctoC.h,v $ $Revision: 1.9 $\
+// using $RCSfile$ $Revision$\
 
 # Make YYSTYPE a struct such that we can store class objects
 # (use anonymous unions to save space!)
-s!^typedef union\(.*\)$!typedef struct _YYSTYPE \1!
+s!^typedef union *[a-zA-Z_]*\(.*\)$!typedef struct _YYSTYPE \1!
 
 # Avoid conflicting re-definitions
 s!YYSTYPE!IGNORED_&!g
 s!yylval!IGNORED_&!g
+s!yystype!IGNORED_&!g
